import unittest
from paycheck import with_checker
from paycheck.generator import *
import sys

class TestGenerator(unittest.TestCase):
    def test_get_int(self):
        self.assertTrue(isinstance(
                    PayCheckGenerator.get(int),
                    IntGenerator
                    ))
        
    def test_get_string(self):
        self.assertTrue(isinstance(
                    PayCheckGenerator.get(str),
                    StringGenerator
                    ))

    if sys.version_info[0] < 3:
        def test_get_unicode(self):
            self.assertTrue(isinstance(
                        PayCheckGenerator.get(unicode),
                        UnicodeGenerator
                        ))
    
    def test_get_boolean(self):
        self.assertTrue(isinstance(
                    PayCheckGenerator.get(bool),
                    BooleanGenerator
                    ))
    
    def test_get_float(self):
        self.assertTrue(isinstance(
                    PayCheckGenerator.get(float),
                    FloatGenerator
                    ))

    @with_checker
    def test_get_iterable(self,values=[int]):
        class CustomGenerator(object):
            def __init__(self,values):
                self.values = values
            def __iter__(self):
                return iter(values)
        self.assertEqual(list(PayCheckGenerator.get(CustomGenerator(values))),values)

    def test_get_custom(self):
        class CustomGenerator(object):
            @classmethod
            def make_new_random_generator(cls):
                return CustomGenerator()
        self.assertTrue(isinstance(
                    PayCheckGenerator.get(CustomGenerator),
                    CustomGenerator
                    ))
    
    def test_get_unknown_type_throws_exception(self):
        class CustomGenerator(object):
            pass
        getter = lambda: PayCheckGenerator.get(CustomGenerator)
        self.assertRaises(UnknownTypeException, getter)
        
    def test_bad_object_throws_exception(self):
        getter = lambda: PayCheckGenerator.get(None)
        self.assertRaises(UnknownTypeException, getter)
        
    def test_get_list_of_type(self):
        generator = PayCheckGenerator.get([int])
        self.assertTrue(isinstance(generator, ListGenerator))
        self.assertTrue(isinstance(generator.inner, IntGenerator))
        
    def test_get_nested_list_of_type(self):
        generator = PayCheckGenerator.get([[int]])
        self.assertTrue(isinstance(generator, ListGenerator))
        self.assertTrue(isinstance(generator.inner, ListGenerator))
        self.assertTrue(isinstance(generator.inner.inner, IntGenerator))
    
    def test_empty_list(self):
        getter = lambda: PayCheckGenerator.get([])
        self.assertRaises(IncompleteTypeException, getter)    

    def test_empty_dict(self):
        getter = lambda: PayCheckGenerator.get({})
        self.assertRaises(IncompleteTypeException, getter)
    
    def test_dict_of_str_int(self):
        generator = PayCheckGenerator.get({str:int})
        self.assertTrue(isinstance(generator, DictGenerator))
        self.assertTrue(isinstance(generator.inner, TupleGenerator))
        self.assertTrue(isinstance(generator.inner.generators[0], StringGenerator))
        self.assertTrue(isinstance(generator.inner.generators[1], IntGenerator))

tests = [TestGenerator]

if __name__ == '__main__':
    unittest.main()



import unittest

from tests import test_basics, test_generator, test_sample, test_strings, test_types, test_usage, test_values
modules = [
    test_basics,
    test_generator,
    test_sample,
    test_strings,
    test_types,
    test_usage,
    test_values
    ]

def run_tests():
    tests = []
    for module in modules:
        for test_case in module.tests:
            tests.append(unittest.defaultTestLoader.loadTestsFromTestCase(test_case))
    unittest.TextTestRunner(verbosity=2).run(unittest.TestSuite(tests))

if __name__ == "__main__":
    run_tests()



import unittest
from paycheck import with_checker
from paycheck.generator import irange

class TestSample(unittest.TestCase):
    
    @with_checker(str, str)
    def test_string_concatination(self, a, b):
        self.assertTrue((a+b).endswith(b))

tests = [TestSample]

if __name__ == '__main__':
    unittest.main()



import unittest
from paycheck import with_checker, irange, frange, choiceof, oneof
import sys

class TestTypes(unittest.TestCase):

    @with_checker(str)
    def test_string(self, s):
        self.assertTrue(isinstance(s, str))

    @with_checker(int)
    def test_int(self, i):
        self.assertTrue(isinstance(i, int))

    @with_checker(irange(1,10))
    def test_irange(self, i):
        self.assertTrue(isinstance(i, int))

    @with_checker(float)
    def test_float(self, f):
        self.assertTrue(isinstance(f, float))

    @with_checker(frange(1,10))
    def test_frange(self, f):
        self.assertTrue(isinstance(f, float))

    @with_checker(complex)
    def test_complex(self, c):
        self.assertTrue(isinstance(c, complex))

    if sys.version_info[0] < 3:
        @with_checker(unicode)
        def test_unicode(self, u):
            self.assertTrue(isinstance(u, unicode) or
                        isinstance(u, str))

    @with_checker(bool)
    def test_boolean(self, b):
        self.assertEqual(b, b == True)

    @with_checker([int])
    def test_get_list(self, list_of_ints):
        self.assertTrue(isinstance(list_of_ints, list))
        for i in list_of_ints:
            self.assertTrue(isinstance(i, int))

    @with_checker(set([str]))
    def test_get_list(self, set_of_strs):
        self.assertTrue(isinstance(set_of_strs, set))
        for s in set_of_strs:
            self.assertTrue(isinstance(s, str))

    @with_checker({str: int})
    def test_get_dict(self, dict_of_str_int):
        self.assertTrue(isinstance(dict_of_str_int, dict))
        for key, value in dict_of_str_int.items():
            self.assertTrue(isinstance(key, str))
            self.assertTrue(isinstance(value, int))

    @with_checker(str, [[bool]])
    def test_nested_types(self, s, list_of_lists_of_bools):
        self.assertTrue(isinstance(s, str))
        self.assertTrue(isinstance(list_of_lists_of_bools, list))
        
        for list_of_bools in list_of_lists_of_bools:
            self.assertTrue(isinstance(list_of_bools, list))
            for b in list_of_bools:
                self.assertTrue(isinstance(b, bool))

    @with_checker(int, {str: int})
    def test_dict_of_str_key_int_values(self, i, dict_of_str_int):
        self.assertTrue(isinstance(i, int))
        self.assertTrue(isinstance(dict_of_str_int, dict))
        
        for key, value in dict_of_str_int.items():
            self.assertTrue(isinstance(key, str))
            self.assertTrue(isinstance(value, int))

    @with_checker([{str: int}])
    def test_list_of_dict_of_int_string(self, list_of_dict_of_int_string):
        self.assertTrue(isinstance(list_of_dict_of_int_string, list))
        
        for dict_of_int_string in list_of_dict_of_int_string:
            self.assertTrue(isinstance(dict_of_int_string, dict))

            for key, value in dict_of_int_string.items():
                self.assertTrue(isinstance(key, str))
                self.assertTrue(isinstance(value, int))

    @with_checker(choiceof(["A","B"]))
    def test_choiceof(self, letter):
        self.assertTrue(letter in ["A","B"])

    @with_checker(oneof("A","B"))
    def test_oneof(self, letter):
        self.assertTrue(letter in ["A","B"])

tests = [TestTypes]

if __name__ == '__main__':
    unittest.main()



import unittest
from paycheck import *
from paycheck import generator

class TestValues(unittest.TestCase):

    @with_checker(irange(0,10))
    def test_irange_range(self,i):
        self.assertTrue(i >= 0)
        self.assertTrue(i <= 10)

    @with_checker(irange(0,10,3))
    def test_irange_step(self,i):
        self.assertEqual(0,i%3)

    @with_checker(irange(-17,86,9))
    def test_irange_exotic(self,i):
        self.assertTrue(i >= -17)
        self.assertTrue(i <= 86)
        self.assertEqual(0,(i+17)%9)

    @with_checker(irange(0,0))
    def test_irange_tiny(self,i):
        self.assertEqual(0,i)

    @with_checker(frange(0,10))
    def test_frange(self,f):
        self.assertTrue(f >=  0)
        self.assertTrue(f <  10)

    @with_checker(unit_interval_float)
    def test_unit_interval_float(self,f):
        self.assertTrue(f >=  0)
        self.assertTrue(f <=  1)

    @with_checker(non_negative_float)
    def test_non_negative_floats(self,f):
        self.assertTrue(f >= 0)

    @with_checker(non_negative_float(1e3,1e5))
    def test_frange(self,f):
        self.assertTrue(f >=  1e3)
        self.assertTrue(f <   1e5)

    @with_checker(positive_float)
    def test_positive_floats(self,f):
        self.assertTrue(f >= 0)

tests = [TestValues]

if __name__ == '__main__':
    unittest.main()



import unittest
from paycheck import with_checker

class TestStrings(unittest.TestCase):
    """
    More-or-less a direct port of the string testing example from the ScalaCheck
    doc at: http://code.google.com/p/scalacheck/
    """
    
    @with_checker(str, str)
    def test_starts_with(self, a, b):
        self.assertTrue((a+b).startswith(a))

    @with_checker(str, str)
    def test_ends_with(self, a, b):
        self.assertTrue((a+b).endswith(b))

    @with_checker(str, str)
    def test_concat(self, a, b):
        self.assertTrue(len(a+b) >= len(a))
        self.assertTrue(len(a+b) >= len(b))

    @with_checker(str, str)
    def test_substring2(self, a, b):
        self.assertEqual( (a+b)[len(a):], b )
    
    @with_checker(str, str, str)
    def test_substring3(self, a, b, c):
        self.assertEqual((a+b+c)[len(a):len(a)+len(b)], b)

tests = [TestStrings]

if __name__ == '__main__':
    unittest.main()



import unittest
from paycheck import with_checker

class TestUsage(unittest.TestCase):

    @with_checker()
    def test_defaults(self, i=int, f=float):
        self.assertTrue(isinstance(i, int))
        self.assertTrue(isinstance(f, float))

    @with_checker(int)
    def test_mixed(self, i, f=float):
        self.assertTrue(isinstance(i, int))
        self.assertTrue(isinstance(f, float))

    @with_checker
    def test_without_parentheses(self, i=int, f=float):
        self.assertTrue(isinstance(i, int))
        self.assertTrue(isinstance(f, float))

tests = [TestUsage]

if __name__ == '__main__':
    unittest.main()



from distutils.cmd import Command
from distutils.core import setup

import sys
if sys.version_info >= (3, 0):
    try:
        from distutils.command.build_py import build_py_2to3 as build_py
    except ImportError:
        raise ImportError("build_py_2to3 not found in distutils - it is required for Python 3.x")
else:
    from distutils.command.build_py import build_py

class test(Command):
    user_options = []
    def initialize_options(self):
        pass
    def finalize_options(self):
        pass
    def run(self):
        import tests
        tests.run_tests()

setup(
    name = 'paycheck',
    version ='1.0',
    description ='A Python QuickCheck implementation',
    author ='Mark Chadwick',
    author_email ='mark.chadwick@gmail.com',
    maintainer ='Gregory Crosswhite',
    maintainer_email ='gcrosswhite@gmail.com',
    license = 'ISC',
    url='http://github.com/gcross/paycheck',
    packages = ['paycheck'],
    cmdclass = {"build_py": build_py, "test" : test}
)



import unittest
from paycheck import with_checker
import sys

class Dummy:
    pass

class TestBasics(unittest.TestCase):
    def test_calls_method(self):
        o = Dummy()
        @with_checker(number_of_calls=10)
        def call_me():
            o.times_called += 1
        o.times_called = 0
        call_me()
        self.assertEqual(10,o.times_called)

    def test_calls_method_without_parentheses(self):
        o = Dummy()
        @with_checker
        def call_me():
            o.times_called += 1
        o.times_called = 0
        call_me()
        self.assertTrue(o.times_called > 0)

    def test_throws_correct_exception_upon_failure(self):
        class MyException(Exception):
            pass
        e = MyException("FAIL")
        @with_checker(number_of_calls=1)
        def call_me():
            raise e
        try:
            call_me()
            self.fail("Exception was not thrown!")
        except MyException:
            pass
        except Exception as root:
            self.assertEqual(root.__context__,e)

tests = [TestBasics]

if __name__ == '__main__':
    unittest.main()
